@@ -15,7 +15,7 @@
 __declspec(noreturn) void MT_exit_thread(int status)
 	__attribute__((__noreturn__));
 __hidden void MT_global_exit(int status)
-	__attribute__((__noreturn__))
+//	__attribute__((__noreturn__))
 	__attribute__((__visibility__("hidden")));
 __hidden int MT_kill_thread(MT_Id t)
 	__attribute__((__visibility__("hidden")));
