@@ -190,7 +190,14 @@ str
 SQLepilogue(void *ret)
 {
 	(void) ret;
+	Client c = mal_clients;
 	if (SQLinitialized) {
+		// exit all clients
+		for (c = mal_clients + 1; c < mal_clients + MAL_MAXCLIENTS; c++) {
+			if (c->mode == RUNCLIENT){
+				SQLexitClient(c);
+			}
+		}
 		mvc_exit();
 		SQLinitialized = FALSE;
 	}
