@@ -1686,7 +1686,7 @@ gtr_update_delta( sql_trans *tr, sql_delta *cbat, int *changes)
 	}
 	bat_destroy(ins);
 
-	if (cbat->ucnt) {
+	if (cbat->ucnt && cbat->uibid) {
 		BAT *ui = temp_descriptor(cbat->uibid);
 		BAT *uv = temp_descriptor(cbat->uvbid);
 		/* any updates */
@@ -1945,7 +1945,7 @@ tr_update_delta( sql_trans *tr, sql_delta *obat, sql_delta *cbat, int unique)
 	}
 	bat_destroy(ins);
 
-	if (cbat->ucnt || cleared) {
+	if ((cbat->ucnt || cleared) && cbat->uibid) {
 		BAT *ui = temp_descriptor(cbat->uibid);
 		BAT *uv = temp_descriptor(cbat->uvbid);
 
@@ -2144,6 +2144,11 @@ update_table(sql_trans *tr, sql_table *ft, sql_table *tt)
 		} else if (tt->data && ft->base.allocated) {
 			tr_update_dbat(tr, tt->data, ft->data, ft->cleared);
 		} else if (store_nr_active == 1 && !ft->base.allocated) {
+			if (!tt->data && tt->po) {
+				sql_table *ot = tr_find_table(tr->parent, tt);
+				tt->data = timestamp_dbat(ot->data, tr->stime);
+			}
+			assert(tt->data);
 			tr_merge_dbat(tr, tt->data);
 			ft->data = NULL;
 		} else if (ft->data) {
@@ -2179,6 +2184,11 @@ update_table(sql_trans *tr, sql_table *ft, sql_table *tt)
 			} else if (oc->data && cc->base.allocated) {
 				tr_update_delta(tr, oc->data, cc->data, cc->unique == 1);
 			} else if (store_nr_active == 1 && !cc->base.allocated) {
+				if (!oc->data) {
+					sql_column *o = tr_find_column(tr->parent, oc);
+					oc->data = timestamp_delta(o->data, tr->stime);
+				}
+				assert(oc->data);
 				tr_merge_delta(tr, oc->data, oc->unique == 1);
 				cc->data = NULL;
 			} else if (cc->data) {
@@ -2239,6 +2249,11 @@ update_table(sql_trans *tr, sql_table *ft, sql_table *tt)
 				} else if (oi->data && ci->base.allocated) {
 					tr_update_delta(tr, oi->data, ci->data, 0);
 				} else if (store_nr_active == 1 && !ci->base.allocated) {
+					if (!oi->data) {
+						sql_idx *o = tr_find_idx(tr->parent, oi);
+						oi->data = timestamp_delta(o->data, tr->stime);
+					}
+					assert(oi->data);
 					tr_merge_delta(tr, oi->data, 0);
 					ci->data = NULL;
 				} else if (ci->data) {
@@ -2294,7 +2309,7 @@ tr_log_delta( sql_trans *tr, sql_delta *cbat, int cleared)
 	}
 	bat_destroy(ins);
 
-	if (cbat->ucnt) {
+	if (cbat->ucnt && cbat->uibid) {
 		BAT *ui = temp_descriptor(cbat->uibid);
 		BAT *uv = temp_descriptor(cbat->uvbid);
 		/* any updates */
